@@ -20,7 +20,9 @@ import tim.prune.GenericFunction;
 import tim.prune.GpsPrune;
 import tim.prune.I18nManager;
 import tim.prune.cmd.EditAltitudeCmd;
+import tim.prune.config.Config;
 import tim.prune.data.DataPoint;
+import tim.prune.data.NumberUtils;
 import tim.prune.data.Track;
 import tim.prune.data.UnitSetLibrary;
 import tim.prune.function.edit.PointAltitudeEdit;
@@ -163,9 +165,10 @@ public class LookupSrtmFunction extends GenericFunction
 	 */
 	private void lookupValues(HashSet<SrtmTile> inTileSet, boolean inOverwriteZeros)
 	{
+		final String diskCachePath = getConfig().getConfigString(Config.KEY_DISK_CACHE);
 		SrtmSource[] tileSources = new SrtmSource[] {
-			new SrtmHighResSource(),
-			new SrtmLowResSource()};
+			new SrtmHighResSource(diskCachePath, getConfig().getConfigString(Config.KEY_EARTHDATA_AUTH)),
+			new SrtmLowResSource(diskCachePath)};
 		String errorMessage = null;
 		final int numTiles = inTileSet.size();
 
@@ -369,7 +372,10 @@ public class LookupSrtmFunction extends GenericFunction
 				if (altitude != SrtmSource.VOID_VAL)
 				{
 					// Found an altitude, so create a command for it
-					edits.add(new PointAltitudeEdit(p, "" + altitude, UnitSetLibrary.UNITS_METRES));
+					// (use UK Locale to force a decimal point when rounding the decimal value
+					// instead of using the locale-specific character like comma)
+					String roundedValue = NumberUtils.formatNumberUk(altitude, 3);
+					edits.add(new PointAltitudeEdit(p, roundedValue, UnitSetLibrary.UNITS_METRES));
 				}
 			}
 		}
