@@ -1,7 +1,6 @@
 package tim.prune.gui;
 
 import java.awt.BorderLayout;
-import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.FlowLayout;
 import java.awt.Font;
@@ -31,6 +30,7 @@ import tim.prune.data.AudioClip;
 import tim.prune.data.Coordinate;
 import tim.prune.data.DataPoint;
 import tim.prune.data.Field;
+import tim.prune.data.FieldList;
 import tim.prune.data.Photo;
 import tim.prune.data.RangeStats;
 import tim.prune.data.Selection;
@@ -53,10 +53,12 @@ public class DetailsDisplay extends GenericDisplay
 	private JLabel _latLabel = null, _longLabel = null;
 	private JLabel _altLabel = null;
 	private JLabel _ptDateLabel = null, _ptTimeLabel = null;
-	private JLabel _descLabel = null;
+	private JLabel _descLabel = null, _commentLabel = null;
 	private JLabel _speedLabel = null, _vSpeedLabel = null;
 	private JLabel _nameLabel = null, _typeLabel = null;
 	private JLabel _filenameLabel = null;
+	private static final int NUM_EXTENSION_LABELS = 5;
+	private final JLabel[] _ptExtensionLabels = new JLabel[NUM_EXTENSION_LABELS];
 
 	// Range details
 	private JLabel _rangeLabel = null;
@@ -124,8 +126,7 @@ public class DetailsDisplay extends GenericDisplay
 		_config = inApp.getConfig();
 		setLayout(new BorderLayout());
 
-		JPanel mainPanel = new JPanel();
-		mainPanel.setLayout(new BoxLayout(mainPanel, BoxLayout.Y_AXIS));
+		BoxPanel mainPanel = BoxPanel.create();
 		mainPanel.setBorder(BorderFactory.createEmptyBorder(3, 3, 3, 3));
 		Font biggerFont = new JLabel().getFont();
 		biggerFont = biggerFont.deriveFont(Font.BOLD, biggerFont.getSize2D() + 2.0f);
@@ -148,6 +149,8 @@ public class DetailsDisplay extends GenericDisplay
 		pointDetailsPanel.add(_ptTimeLabel);
 		_descLabel = new JLabel("");
 		pointDetailsPanel.add(_descLabel);
+		_commentLabel = new JLabel("");
+		pointDetailsPanel.add(_commentLabel);
 		_speedLabel = new JLabel("");
 		pointDetailsPanel.add(_speedLabel);
 		_vSpeedLabel = new JLabel("");
@@ -158,7 +161,10 @@ public class DetailsDisplay extends GenericDisplay
 		pointDetailsPanel.add(_typeLabel);
 		_filenameLabel = new JLabel("");
 		pointDetailsPanel.add(_filenameLabel);
-		pointDetailsPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
+		for (int i=0; i<NUM_EXTENSION_LABELS; i++) {
+			_ptExtensionLabels[i] = new JLabel("example");
+			pointDetailsPanel.add(_ptExtensionLabels[i]);
+		}
 
 		// range details panel
 		JPanel rangeDetailsPanel = makeDetailsPanel("details.rangedetails", biggerFont);
@@ -174,7 +180,6 @@ public class DetailsDisplay extends GenericDisplay
 		rangeDetailsPanel.add(_altRangeLabel);
 		_updownLabel = new JLabel("");
 		rangeDetailsPanel.add(_updownLabel);
-		rangeDetailsPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
 
 		// photo details panel
 		_photoDetailsPanel = makeDetailsPanel("details.photodetails", biggerFont);
@@ -203,7 +208,6 @@ public class DetailsDisplay extends GenericDisplay
 		_rotationButtons.add(rotRight);
 		_rotationButtons.add(Box.createHorizontalStrut(10));
 		_rotationButtons.add(popup);
-		_rotationButtons.setAlignmentX(Component.LEFT_ALIGNMENT);
 		_rotationButtons.setVisible(false);
 		_photoDetailsPanel.add(_rotationButtons);
 		_photoDetailsPanel.setVisible(false);
@@ -233,7 +237,6 @@ public class DetailsDisplay extends GenericDisplay
 		_playAudioPanel.add(playAudio);
 		JButton stopAudio = makeRotateButton(iconManager, IconManager.CONTROL_STOP, FunctionLibrary.FUNCTION_STOP_AUDIO);
 		_playAudioPanel.add(stopAudio);
-		_playAudioPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
 		_playAudioPanel.setVisible(false);
 		_audioDetailsPanel.add(_playAudioPanel);
 		_audioDetailsPanel.setVisible(false);
@@ -251,24 +254,21 @@ public class DetailsDisplay extends GenericDisplay
 		add(mainPanel, BorderLayout.NORTH);
 
 		// Add format, units selection
-		JPanel lowerPanel = new JPanel();
-		lowerPanel.setLayout(new BoxLayout(lowerPanel, BoxLayout.Y_AXIS));
+		BoxPanel lowerPanel = BoxPanel.create();
 		JLabel coordFormatLabel = new JLabel(I18nManager.getText("details.coordformat") + ": ");
-		coordFormatLabel.setAlignmentX(Component.LEFT_ALIGNMENT);
 		lowerPanel.add(coordFormatLabel);
 		String[] coordFormats = {I18nManager.getText("units.original"), I18nManager.getText("units.degminsec"),
 			I18nManager.getText("units.degmin"), I18nManager.getText("units.deg")};
 		_coordFormatDropdown = new JComboBox<String>(coordFormats);
 		_coordFormatDropdown.addActionListener(e -> dataUpdated(DataSubscriber.UNITS_CHANGED));
 		lowerPanel.add(_coordFormatDropdown);
-		_coordFormatDropdown.setAlignmentX(Component.LEFT_ALIGNMENT);
 		JLabel unitsLabel = new JLabel(I18nManager.getText("details.distanceunits") + ": ");
-		unitsLabel.setAlignmentX(Component.LEFT_ALIGNMENT);
 		lowerPanel.add(unitsLabel);
 		// Make dropdown for distance units
 		_distUnitsDropdown = new JComboBox<String>();
 		final UnitSet currUnits = _config.getUnitSet();
-		for (int i=0; i<UnitSetLibrary.getNumUnitSets(); i++) {
+		for (int i=0; i<UnitSetLibrary.getNumUnitSets(); i++)
+		{
 			_distUnitsDropdown.addItem(I18nManager.getText(UnitSetLibrary.getUnitSet(i).getDistanceUnit().getNameKey()));
 			if (UnitSetLibrary.getUnitSet(i) == currUnits) {
 				_distUnitsDropdown.setSelectedIndex(i);
@@ -279,7 +279,6 @@ public class DetailsDisplay extends GenericDisplay
 			UpdateMessageBroker.informSubscribers(DataSubscriber.UNITS_CHANGED);
 		});
 		lowerPanel.add(_distUnitsDropdown);
-		_distUnitsDropdown.setAlignmentX(Component.LEFT_ALIGNMENT);
 		add(lowerPanel, BorderLayout.SOUTH);
 	}
 
@@ -318,11 +317,13 @@ public class DetailsDisplay extends GenericDisplay
 			_ptDateLabel.setText("");
 			_ptTimeLabel.setText("");
 			_descLabel.setText("");
+			_commentLabel.setText("");
 			_nameLabel.setText("");
 			_typeLabel.setText("");
 			_speedLabel.setText("");
 			_vSpeedLabel.setText("");
 			_filenameLabel.setText("");
+			clearPointExtensionLabels();
 		}
 		else
 		{
@@ -411,6 +412,7 @@ public class DetailsDisplay extends GenericDisplay
 				_filenameLabel.setText("");
 				_filenameLabel.setToolTipText("");
 			}
+			setPointExtensionLabels(currentPoint);
 		}
 
 		// Update range details
@@ -537,39 +539,67 @@ public class DetailsDisplay extends GenericDisplay
 		_playAudioPanel.setVisible(currentAudio != null);
 	}
 
+	private void clearPointExtensionLabels()
+	{
+		for (JLabel label : _ptExtensionLabels) {
+			label.setText("");
+		}
+	}
+
+	private void setPointExtensionLabels(DataPoint inPoint)
+	{
+		int labelIndex = 0;
+		FieldList fields = inPoint.getFieldList();
+		for (int i=0; i<fields.getNumFields(); i++)
+		{
+			Field field = fields.getField(i);
+			if (field.isBuiltIn() || labelIndex >= NUM_EXTENSION_LABELS) {
+				continue;
+			}
+			String value = inPoint.getFieldValue(field);
+			if (value != null && !value.isEmpty() && !field.isBuiltIn())
+			{
+				_ptExtensionLabels[labelIndex].setText(field.getName() + ": " + value);
+				labelIndex++;
+			}
+		}
+		// Clear the ones afterwards
+		while (labelIndex < NUM_EXTENSION_LABELS)
+		{
+			_ptExtensionLabels[labelIndex].setText("");
+			labelIndex++;
+		}
+	}
+
 	/** Set either the description or comment from the current point */
 	private void showDescriptionOrComment(DataPoint inPoint)
 	{
 		String desc = inPoint.getFieldValue(Field.DESCRIPTION);
-		if (desc != null && !desc.isEmpty()) {
-			showDescriptionOrComment(LABEL_POINT_DESCRIPTION, desc);
-			return;
-		}
+		showDescriptionOrComment(_descLabel, LABEL_POINT_DESCRIPTION, desc);
 		String comment = inPoint.getFieldValue(Field.COMMENT);
-		if (comment != null && !comment.isEmpty()) {
-			showDescriptionOrComment(LABEL_POINT_COMMENT, comment);
-			return;
+		if (comment == null || comment.isEmpty() || comment.equals(desc)) {
+			comment = "";
 		}
-		showDescriptionOrComment("", "");
+		showDescriptionOrComment(_commentLabel, LABEL_POINT_COMMENT, comment);
 	}
 
-	/** Set the description label and its tooltip */
-	private void showDescriptionOrComment(String inPrefix, String inValue)
+	/** Set the description or comment label and its tooltip */
+	private void showDescriptionOrComment(JLabel inLabel, String inPrefix, String inValue)
 	{
-		if (inPrefix.isEmpty() || inValue.isEmpty())
+		if (inPrefix.isEmpty() || inValue == null || inValue.isEmpty())
 		{
-			_descLabel.setText("");
-			_descLabel.setToolTipText("");
+			inLabel.setText("");
+			inLabel.setToolTipText("");
 		}
 		else
 		{
 			if (inValue.length() < 10) {
-				_descLabel.setText(inPrefix + inValue);
+				inLabel.setText(inPrefix + inValue);
 			}
 			else {
-				_descLabel.setText(shortenString(inValue));
+				inLabel.setText(shortenString(inValue));
 			}
-			_descLabel.setToolTipText(inPrefix + inValue);
+			inLabel.setToolTipText(inPrefix + inValue);
 		}
 	}
 
