@@ -8,6 +8,6 @@ public class AudioFileFilter extends GenericFileFilter
 	/** Constructor */
 	public AudioFileFilter()
 	{
-		super("filetype.audio", new String[] {"mp3", "ogg", "wav"});
+		super("filetypefilter.audio", new String[] {"mp3", "ogg", "wav"});
 	}
 }
